---
sidebar_label: PDFOptions
---

# PDFOptions interface

Valid options to configure PDF generation via [Page.pdf()](./puppeteer.page.pdf.md).

#### Signature:

```typescript
export interface PDFOptions
```

## Properties

| Property                                                              | Modifiers | Type                                      | Description                                                                                                                                                                                                                                                                                                                                                                                       | Default                                                                 |
| --------------------------------------------------------------------- | --------- | ----------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------- |
| [displayHeaderFooter?](./puppeteer.pdfoptions.displayheaderfooter.md) |           | boolean                                   | <i>(Optional)</i> Whether to show the header and footer.                                                                                                                                                                                                                                                                                                                                          | false                                                                   |
| [footerTemplate?](./puppeteer.pdfoptions.footertemplate.md)           |           | string                                    | <i>(Optional)</i> HTML template for the print footer. Has the same constraints and support for special classes as [PDFOptions.headerTemplate](./puppeteer.pdfoptions.headertemplate.md).                                                                                                                                                                                                          |                                                                         |
| [format?](./puppeteer.pdfoptions.format.md)                           |           | [PaperFormat](./puppeteer.paperformat.md) | <i>(Optional)</i>                                                                                                                                                                                                                                                                                                                                                                                 | <code>letter</code>.                                                    |
| [headerTemplate?](./puppeteer.pdfoptions.headertemplate.md)           |           | string                                    | <p><i>(Optional)</i> HTML template for the print header. Should be valid HTML with the following classes used to inject values into them:</p><p>- <code>date</code> formatted print date</p><p>- <code>title</code> document title</p><p>- <code>url</code> document location</p><p>- <code>pageNumber</code> current page number</p><p>- <code>totalPages</code> total pages in the document</p> |                                                                         |
| [height?](./puppeteer.pdfoptions.height.md)                           |           | string \| number                          | <i>(Optional)</i> Sets the height of paper. You can pass in a number or a string with a unit.                                                                                                                                                                                                                                                                                                     |                                                                         |
| [landscape?](./puppeteer.pdfoptions.landscape.md)                     |           | boolean                                   | <i>(Optional)</i> Whether to print in landscape orientation.                                                                                                                                                                                                                                                                                                                                      | = false                                                                 |
| [margin?](./puppeteer.pdfoptions.margin.md)                           |           | [PDFMargin](./puppeteer.pdfmargin.md)     | <i>(Optional)</i> Set the PDF margins.                                                                                                                                                                                                                                                                                                                                                            | no margins are set.                                                     |
| [omitBackground?](./puppeteer.pdfoptions.omitbackground.md)           |           | boolean                                   | <i>(Optional)</i> Hides default white background and allows generating pdfs with transparency.                                                                                                                                                                                                                                                                                                    | false                                                                   |
| [pageRanges?](./puppeteer.pdfoptions.pageranges.md)                   |           | string                                    | <i>(Optional)</i> Paper ranges to print, e.g. <code>1-5, 8, 11-13</code>.                                                                                                                                                                                                                                                                                                                         | The empty string, which means all pages are printed.                    |
| [path?](./puppeteer.pdfoptions.path.md)                               |           | string                                    | <i>(Optional)</i> The path to save the file to.                                                                                                                                                                                                                                                                                                                                                   | the empty string, which means the PDF will not be written to disk.      |
| [preferCSSPageSize?](./puppeteer.pdfoptions.prefercsspagesize.md)     |           | boolean                                   | <i>(Optional)</i> Give any CSS <code>@page</code> size declared in the page priority over what is declared in the <code>width</code> or <code>height</code> or <code>format</code> option.                                                                                                                                                                                                        | <code>false</code>, which will scale the content to fit the paper size. |
| [printBackground?](./puppeteer.pdfoptions.printbackground.md)         |           | boolean                                   | <i>(Optional)</i> Set to <code>true</code> to print background graphics.                                                                                                                                                                                                                                                                                                                          | false                                                                   |
| [scale?](./puppeteer.pdfoptions.scale.md)                             |           | number                                    | <i>(Optional)</i> Scales the rendering of the web page. Amount must be between <code>0.1</code> and <code>2</code>.                                                                                                                                                                                                                                                                               | 1                                                                       |
| [timeout?](./puppeteer.pdfoptions.timeout.md)                         |           | number                                    | <i>(Optional)</i> Timeout in milliseconds                                                                                                                                                                                                                                                                                                                                                         | 30000                                                                   |
| [width?](./puppeteer.pdfoptions.width.md)                             |           | string \| number                          | <i>(Optional)</i> Sets the width of paper. You can pass in a number or a string with a unit.                                                                                                                                                                                                                                                                                                      |                                                                         |
